@@ -1,7 +1,8 @@
-from db import db
+from ext import EXT_CONTEXT
 from sqlalchemy import Column, Integer, String
 
-class Goods(db.Model):
+
+class Goods(EXT_CONTEXT["db"].Model):
 
     __tablename__ = 'goods'
 
